San Lameer Resort Hotel & Spa
Description: San Lameer Resort Hotel and Spa in Southbroom on the KwaZulu Natal South Coast is situated on the banks of the Umhlangamkulu Lagoon with access to to beach.
Keywords: San Lameer, San Lameer Hotel, San Lameer accommodation, Southbroom, San Lameer Golf, southbrook accommodation, camelot spa, san lameer country club, san lameer,

# The perfect coastal escape.

San Lameer Resort Hotel & Spa is situated on the iconic San Lameer Estate near Southbroom on the KwaZulu Natal South Coast. The hotel itself is situated on the banks of the tidal Umhlangamkulu Lagoon and Guests have direct access to pristine Blue Flag Indian Ocean beaches.

The intimate hotel offers 40 rooms and suites elegantly decorated in contemporary Indonesian style. In this exclusive and secure beach and golf coastal reserve, guests are surrounded by beauty, luxury and tranquility. The centrepiece of San Lameer’s magnificent domain is the 18-hole championship golf course which has recently hosted the SA Womens Open. For the non-Golfer there are a myriad of facilities and activities on the estate to keep you occupied, not least of all the award winning Camelot Spa.

- ## Rooms

- ## Spa

- ## Golf

- ## Dining

- ## Weddings

- ## Conferencing

### Special Offers

- ## Spa Package

- ## Golf Package

Previous Next
1 2

- ## Dinner Bed & Breakfast

- ## Family Package

Previous Next
1 2
Scroll to top